@@ -1,11 +1,13 @@
-package DB::Pluggable;
-use 5.006;
+use 5.008;
 use strict;
 use warnings;
+
+package DB::Pluggable;
+our $VERSION = '1.100850';
+# ABSTRACT: Add plugin support for the Perl debugger
 use DB::Pluggable::Constants ':all';
 use Hook::LexWrap;
-use base 'Hook::Modular';
-our $VERSION = '0.04';
+use parent 'Hook::Modular';
 use constant PLUGIN_NAMESPACE => 'DB::Pluggable';
 
 sub enable_watchfunction {
@@ -13,28 +15,6 @@ sub enable_watchfunction {
     no warnings 'once';
     $DB::trace |= 4;    # Enable watchfunction
 }
-package                 # hide from PAUSE indexer
-  DB;
-
-# switch package so as to get the desired stack trace
-sub watchfunction {
-    return unless defined $DB::PluginHandler;
-    my $depth = 1;
-    while (1) {
-        my ($package, $file, $line, $sub) = caller $depth;
-        last unless defined $package;
-        return if $sub =~ /::DESTROY$/;
-        $depth++;
-    }
-    $DB::PluginHandler->run_hook('db.watchfunction');
-}
-
-sub afterinit {
-    return unless defined $DB::PluginHandler;
-    $DB::PluginHandler->run_hook('db.afterinit');
-}
-
-package DB::Pluggable;
 
 sub run {
     my $self = shift;
@@ -54,17 +34,45 @@ sub run {
         $_[-1] = 1 if grep { $_ eq HANDLED } @result;
     };
 }
-1;
-__END__
 
-=for test_synopsis
 1;
+
+package                 # hide from PAUSE indexer
+  DB;
+our $VERSION = '1.100850';
+
+# switch package so as to get the desired stack trace
+sub watchfunction {
+    return unless defined $DB::PluginHandler;
+    my $depth = 1;
+    while (1) {
+        my ($package, $file, $line, $sub) = caller $depth;
+        last unless defined $package;
+        return if $sub =~ /::DESTROY$/;
+        $depth++;
+    }
+    $DB::PluginHandler->run_hook('db.watchfunction');
+}
+
+sub afterinit {
+    return unless defined $DB::PluginHandler;
+    $DB::PluginHandler->run_hook('db.afterinit');
+}
+
+1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 DB::Pluggable - Add plugin support for the Perl debugger
 
+=head1 VERSION
+
+version 1.100850
+
 =head1 SYNOPSIS
 
     $ cat ~/.perldb
@@ -97,6 +105,27 @@ more commented one in this distribution's C<etc/perldb> file.
 Plugins should live in the C<DB::Pluggable::> namespace, like
 L<DB::Pluggable::BreakOnTestNumber> does.
 
+=head1 METHODS
+
+=head2 enable_watchfunction
+
+Tells the debugger to call C<DB::watchfunction()>, which in turn calls the
+C<db.watchfunction> hook on all plugins that have registered it.
+
+=head2 run
+
+First it calls the C<plugin.init> hook, then it enables hooks for the relevant
+debugger commands (see above for which hooks are available).
+
+Each command-related hook should return the appropriate constant from
+L<DB::Pluggable::Constants> - either C<HANDLED> if the hook has handled the
+command, or C<DECLINED> if it didn't. If no hook has C<HANDLED> the command,
+the default command subroutine (e.g., C<DB::cmd_b()>) from C<perl5db.pl>
+will be called.
+
+=for test_synopsis 1;
+__END__
+
 =head1 HOOKS
 
 This class is very much in beta, so it's more like a proof of concept.
@@ -149,58 +178,39 @@ This is the third argument passed to C<DB::cmd_b()>.
 
 =back
 
-=head1 METHODS
+=head1 INSTALLATION
 
-=over 4
-
-=item C<enable_watchfunction>
-
-Tells the debugger to call C<DB::watchfunction()>, which in turn calls the
-C<db.watchfunction> hook on all plugins that have registered it.
-
-=item C<run>
-
-First it calls the C<plugin.init> hook, then it enables hooks for the relevant
-debugger commands (see above for which hooks are available).
-
-Each command-related hook should return the appropriate constant from
-L<DB::Pluggable::Constants> - either C<HANDLED> if the hook has handled the
-command, or C<DECLINED> if it didn't. If no hook has C<HANDLED> the command,
-the default command subroutine (e.g., C<DB::cmd_b()>) from C<perl5db.pl>
-will be called.
-
-=back
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=DB-Pluggable>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/DB-Pluggable/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/DB-Pluggable/>.
 
-The development version lives at L<http://github.com/hanekomu/db-pluggable/>.
+The development version lives at
+L<http://github.com/hanekomu/DB-Pluggable/>.
 Instead of sending patches, please fork this project using the standard git
 and github infrastructure.
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 by Marcel GrE<uuml>nauer.
+This software is copyright (c) 2008 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
